@@ -23,8 +23,8 @@ def test_get_deployments(logged_in_context):
     runner = CliRunner()
     result = runner.invoke(get.get_deployment_by_repo_id)
     assert result.exit_code == 0, result.output
-    assert "2732fdb2-67e4-428f-ac7d-72f379376b67" in result.output
-    assert "582132db-6687-4c87-9907-ffbc8f03fa07" in result.output
+    assert "395391a4-a4c8-4671-8dc4-9423fecb5e4a" in result.output
+    assert "c3da3eb8-2fce-434b-96f0-6a78a200234b" in result.output
 
     as_io = StringIO(result.output)
     lines = as_io.readlines()
@@ -36,7 +36,8 @@ def test_get_deployments_with_options(logged_in_context):
     result_with_id = runner.invoke(
         get.get_deployment_by_repo_id, "99ffb2dc-b06d-4262-b2e0-34cd40a0c56d"
     )
-    assert "refs/heads/master @ 344e3bc" in result_with_id.output
+    assert "refs/heads/master" in result_with_id.output
+    assert "e6eec3d" in result_with_id.output
     as_io = StringIO(result_with_id.output)
     lines = as_io.readlines()
     assert len(lines) == 3, lines
