@@ -19,9 +19,15 @@ from tktl.commands.run import run_container
     required=False,
 )
 @click.option(
-    "--nocache/--cache",
+    "--cache/--disable-cache",
     help="Enable or disable using cache of images",
     is_flag=True,
+    default=True,
+)
+@click.option(
+    "--prune/--disable-prune",
+    help="Enable or disable automatic pruning of images",
+    is_flag=True,
     default=False,
 )
 @click.option("--background", help="Run the image in the background", is_flag=True)
@@ -38,7 +44,8 @@ from tktl.commands.run import run_container
 )
 def run(
     path: str,
-    nocache: bool,
+    cache: bool,
+    prune: bool,
     background: bool,
     auth: bool,
     color: bool,
@@ -46,24 +53,12 @@ def run(
 ) -> None:
     """
     Run a deployment locally
-
-    Parameters
-    ----------
-    auth
-    background
-    nocache
-    path
-    color
-    secrets_repository
-
-    Returns
-    -------
-
     """
     secrets = get_secrets(secrets_repository=secrets_repository)
     run_container(
         path=path,
-        nocache=nocache,
+        cache=cache,
+        prune=prune,
         background=background,
         auth_enabled=auth,
         color_logs=color,
