@@ -1,10 +1,10 @@
 import os
-from typing import Dict
+import typing as t
 
 from docker.errors import APIError  # type: ignore
 from pydantic import ValidationError
 
-from tktl.core.exceptions.exceptions import (
+from tktl.core.exceptions import (
     MissingDocker,
     NoContentsFoundException,
     UserRepoValidationException,
@@ -21,6 +21,7 @@ from tktl.core.validation.outputs import (
 
 def validate_project_config(path: str):
     try:
+        LOG.log("=== VALIDATE PROJECT CONFIG STEP ===")
         ProjectManager.validate_project_config(path)
     except ValidationError as e:
         validation_output = ProjectValidationOutput(
@@ -47,30 +48,34 @@ def log_failure(validation_output: ProjectValidationOutput):
     LOG.log(validation_output.text, color="red", err=True)
 
 
-def build_image(path: str, nocache: bool = False, secrets: Dict[str, str] = None):
+def build_image(path: str, cache: bool, prune: bool, secrets: t.Dict[str, str] = None):
     dm = DockerManager(path)
     LOG.log("Building docker image...")
     abs_path = os.path.abspath(os.path.join(path, ".buildfile"))
-    image = dm.build_image(dockerfile=abs_path, nocache=nocache, buildargs=secrets)
+    image = dm.build_image(
+        dockerfile=abs_path, cache=cache, prune=prune, buildargs=secrets
+    )
 
     return dm, image
 
 
-def status_output(status):
-    if status["StatusCode"] == 0:
+def status_output(status, allowed_status_codes: t.List[int] = [0]):
+    if status["StatusCode"] in allowed_status_codes:
         LOG.log("Success", color="green")
     else:
         LOG.log("Error", color="red")
         exit(1)
 
 
-def validate_import(path: str, nocache: bool, secrets: Dict[str, str] = None):
+def validate_import(
+    path: str, cache: bool, prune: bool, secrets: t.Dict[str, str] = None
+):
     try:
-        dm, image = build_image(path, nocache=nocache, secrets=secrets)
-        LOG.log("Testing import of tktl...")
+        dm, image = build_image(path, cache=cache, prune=prune, secrets=secrets)
+        LOG.log("=== VALIDATE IMPORT STEP ===")
         status, _ = dm.test_import(image)
         status_output(status)
-        if nocache:
+        if prune:
             dm.remove_image(image=image)
 
     except MissingDocker:
@@ -80,13 +85,33 @@ def validate_import(path: str, nocache: bool, secrets: Dict[str, str] = None):
         )
 
 
-def validate_unittest(path: str, nocache: bool, secrets: Dict[str, str] = None):
+def validate_endpoint_sample(
+    path: str, cache: bool, prune: bool, secrets: t.Dict[str, str] = None
+):
     try:
-        dm, image = build_image(path=path, nocache=nocache, secrets=secrets)
-        LOG.log("Running unittests...")
-        status, _ = dm.test_unittest(image)
+        LOG.log("=== VALIDATE ENDPOINT SAMPLE DATA STEP ===")
+        dm, image = build_image(path, cache=cache, prune=prune, secrets=secrets)
+        status, _ = dm.test_endpoint_sample(image)
         status_output(status)
-        if nocache:
+        if prune:
+            dm.remove_image(image=image)
+
+    except MissingDocker:
+        LOG.log(
+            "Couldn't locate docker, please make sure it is installed, or use the DOCKER_HOST environment variable",
+            color="red",
+        )
+
+
+def validate_unittest(
+    path: str, cache: bool, prune: bool, secrets: t.Dict[str, str] = None
+):
+    try:
+        dm, image = build_image(path=path, cache=cache, prune=prune, secrets=secrets)
+        LOG.log("=== VALIDATE UNITTEST STEP ===")
+        status, _ = dm.test_unittest(image)
+        status_output(status, [0, 5])
+        if prune:
             dm.remove_image(image=image)
 
     except MissingDocker:
@@ -97,10 +122,16 @@ def validate_unittest(path: str, nocache: bool, secrets: Dict[str, str] = None):
 
 
 def validate_integration(
-    path: str, nocache: bool, timeout: int, retries: int, secrets: Dict[str, str] = None
+    path: str,
+    cache: bool,
+    prune: bool,
+    timeout: int,
+    retries: int,
+    secrets: t.Dict[str, str] = None,
 ):
     try:
-        dm, image = build_image(path, nocache=nocache, secrets=secrets)
+        dm, image = build_image(path, cache=cache, prune=prune, secrets=secrets)
+        LOG.log("=== VALIDATE INTEGRATION STEP ===")
         LOG.log("Waiting for service to start...")
         (
             rest_response,
@@ -123,7 +154,7 @@ def validate_integration(
                 "Unable to run container. See stack trace for more info", color="red"
             )
             exit(1)
-        if nocache:
+        if prune:
             dm.remove_image(image=image)
 
     except MissingDocker:
@@ -134,11 +165,16 @@ def validate_integration(
 
 
 def validate_profiling(
-    path: str, nocache: bool, timeout: int, retries: int, secrets: Dict[str, str] = None
+    path: str,
+    cache: bool,
+    prune: bool,
+    timeout: int,
+    retries: int,
+    secrets: t.Dict[str, str] = None,
 ):
     try:
-        dm, image = build_image(path, nocache=nocache, secrets=secrets)
-        LOG.log("Testing profiling...")
+        dm, image = build_image(path, cache=cache, prune=prune, secrets=secrets)
+        LOG.log("=== VALIDATE PROFILING STEP ===")
         LOG.log("Initiating service...")
         (
             rest_response,
@@ -165,13 +201,13 @@ def validate_profiling(
             LOG.log("Initiating remote profiling...")
             status, container = dm.run_profiling_container()
             status_output(status)
-            if nocache:
+            if prune:
                 dm.remove_image(image=container.image.id)
         finally:
             try:
                 arrow_container.kill()
                 rest_container.kill()
-                if nocache:
+                if prune:
                     dm.remove_image(image=rest_container.image.id)
                     dm.remove_image(image=arrow_container.image.id)
             except APIError:
@@ -209,14 +245,30 @@ def _validate_container_response(rest_response, grpc_response):
 
 
 def validate_all(
-    path: str, nocache: bool, timeout: int, retries: int, secrets: Dict[str, str] = None
+    path: str,
+    cache: bool,
+    prune: bool,
+    timeout: int,
+    retries: int,
+    secrets: t.Dict[str, str] = None,
 ):
     validate_project_config(path)
-    validate_import(path, nocache=nocache, secrets=secrets)
-    validate_unittest(path, nocache=False, secrets=secrets)
+    validate_import(path, cache=cache, prune=prune, secrets=secrets)
+    validate_endpoint_sample(path, cache=cache, prune=prune, secrets=secrets)
+    validate_unittest(path, cache=cache, prune=prune, secrets=secrets)
     validate_integration(
-        path, nocache=False, timeout=timeout, retries=retries, secrets=secrets
+        path,
+        cache=True,
+        prune=prune,
+        timeout=timeout,
+        retries=retries,
+        secrets=secrets,
     )
     validate_profiling(
-        path, nocache=False, timeout=timeout, retries=retries, secrets=secrets
+        path,
+        cache=True,
+        prune=prune,
+        timeout=timeout,
+        retries=retries,
+        secrets=secrets,
     )
