@@ -12,8 +12,7 @@ from tktl.core.clients.utils import (
     filter_repositories,
 )
 from tktl.core.config import settings
-from tktl.core.exceptions import TaktileSdkError
-from tktl.core.exceptions.exceptions import APIClientException
+from tktl.core.exceptions import APIClientException, TaktileSdkError
 from tktl.core.loggers import LOG
 from tktl.core.schemas.deployment import DeploymentBase
 from tktl.core.schemas.repository import (
@@ -31,7 +30,7 @@ class DeploymentApiClient(API):
     SCHEME: str
 
     def __init__(self, api_key: str):
-        super().__init__(settings.DEPLOYMENT_API_URL)
+        super().__init__(settings.DEPLOYMENT_API_URL, headers={"X-Api-Key": api_key})
         self._api_key = api_key
 
     @lru_cache(timeout=50, typed=False)
