@@ -12,9 +12,10 @@ from requests import ConnectionError, Timeout
 
 from tktl.core.clients.future.http import API
 from tktl.core.config import settings
-from tktl.core.exceptions.exceptions import (
+from tktl.core.exceptions import (
     APIClientException,
     APIClientExceptionRetryable,
+    APISwitchException,
 )
 from tktl.core.loggers import LOG
 from tktl.core.serializers import deserialize_arrow, serialize_arrow
@@ -31,7 +32,13 @@ DO_NOT_RETRY_STATUS_CODES = [
 
 
 def safe_post(
-    *, api: API, url: str, data: t.Any, retries: int = 3, timeout: float = 10.0
+    *,
+    api: API,
+    url: str,
+    json: t.Optional[t.Any] = None,
+    data: t.Optional[str] = None,
+    retries: int = 3,
+    timeout: float = 30.0,
 ):
     """safe_post.
     HTTP POST request with retrying
@@ -42,7 +49,9 @@ def safe_post(
         the underlying api
     url : str
         url to make the request to
-    data : t.Any
+    json: t.Any
+        data to be sent
+    data: str
         data to be sent
     retries : int
         retries
@@ -74,13 +83,22 @@ def safe_post(
     )
     def wrapped():
         try:
-            response = api.post(url=url, data=data, timeout=timeout)
+            if data is not None and json is not None:
+                raise APIClientException(
+                    status_code=HTTPStatus.BAD_REQUEST,
+                    detail="Both JSON and Data parameter can not be set.",
+                )
+            response = api.post(url=url, data=data, json=json, timeout=timeout)
         except (Timeout, ConnectionError) as e:
             raise APIClientExceptionRetryable(
                 status_code=-1, detail="A connection error has occured"
             ) from e
 
-        if response.status_code in DO_NOT_RETRY_STATUS_CODES:
+        if response.status_code == HTTPStatus.NOT_FOUND:
+            # TODO: remove this in taktile-cli 1.0
+            raise APISwitchException
+
+        elif response.status_code in DO_NOT_RETRY_STATUS_CODES:
             if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
                 raise APIClientException(
                     status_code=response.status_code,
@@ -183,7 +201,9 @@ def _get_chunk_size(sample_table: Table) -> t.Tuple[t.Optional[int], t.Optional[
     try:
         mem_per_record = sample_table.nbytes / sample_table.num_rows
     except ZeroDivisionError:
-        LOG.warning("Empty dataframe received")
+        LOG.error(
+            "Empty payload received, which is currently not supported for arrow endpoints"
+        )
         return None, None
     batch_size = math.ceil(settings.ARROW_BATCH_MB * 1e6 / mem_per_record)
     batch_memory_mb = (batch_size * mem_per_record) / 1e6
