@@ -11,7 +11,6 @@ TEMPLATE_PROJECT_FILES = [
     "template/tests/test_accuracy.py",
     "template/tests/test_plausibility.py",
     "template/tests/test_schema.py",
-    "template/tests/test_taktile_endpoint_tests.py",
     "template/.gitignore",
     "template/.gitattributes",
     "template/.buildfile",
@@ -22,20 +21,26 @@ TEMPLATE_PROJECT_FILES = [
 
 
 CONFIG_FILE_TEMPLATE = """
+# See the full documentation at https://docs.taktile.com/configuring-taktile/deployment-configuration
+
 # If this option is set only commits with a commit message starting
-# by the deployment_prefix will be deployed
+# with the deployment_prefix will be deployed
 # deployment_prefix: "#deploy"
 
+# If this option is set commits with a commit message starting
+# with the undeployment_prefix will cause an existing Taktile
+# deployment to no longer be deployed
+# undeployment_prefix: "#undeploy"
+
 service:
 
-  # For the `instance_type` format, use the following: <instance_kind>.<instance_size>
-  # Only 'gp' (general purpose) instance_kind is supported for now
-  # instance_size can be: small, medium, large, xlarge, or xxlarge.
-  # This is the instance type that will be used for both arrow and rest
-
   # Rest deployment scaling parameters
   rest:
-    instance_type: gp.small
+    # requests determine the size of each replica. CPU should be specified as 'XXXm', where XXX is
+    # thousandths of a core, up to 1000. Memory can be specified in base 2 units (Mi or Gi)
+    requests:
+      cpu: 500m
+      memory: 512Mi
     # Maximum and minimum number of replicas to which the REST service is allowed to reach
     # by the auto-scaler
     max_replicas: 1
@@ -44,8 +49,10 @@ service:
 
   # Arrow deployment scaling parameters
   arrow:
-    instance_type: gp.small
-    # Arrow # replicas are fixed and don't autoscale
+    requests:
+      cpu: 500m
+      memory: 512Mi
+    # Arrow replicas are fixed and don't autoscale
     replicas: 1
 
 version: {version}
