@@ -3,9 +3,12 @@ import time
 from typing import Dict
 
 import docker  # type: ignore
+import requests
+from requests.exceptions import RequestException
 
 from tktl.commands.health import GetGrpcHealthCommand, GetRestHealthCommand
-from tktl.core.exceptions.exceptions import APIClientException, MissingDocker
+from tktl.core.config import settings
+from tktl.core.exceptions import APIClientException, MissingDocker
 from tktl.core.loggers import LOG, MUTE_LOG
 
 TESTING_DOCKERFILE = "Dockerfile.taktile-cli-testing"
@@ -61,26 +64,29 @@ class DockerManager:
         self._client.images.remove(image, force=True)
 
     def build_image(
-        self, dockerfile: str, nocache: bool = False, buildargs: Dict = None
+        self, dockerfile: str, cache: bool, prune: bool, buildargs: Dict = None
     ) -> str:
 
-        if nocache:
+        if prune:
             try:
                 image = self._client.images.get("taktile-cli-test:latest")
                 self._client.images.remove(image.id)
             except docker.errors.ImageNotFound:
                 pass
 
+        if not cache:
+            LOG.log("Building without Docker cache. This may take some time...")
+
         # TODO: After phasing out support for non multistage docker files, remove this.
         if DockerManager._is_multi_stage(dockerfile):
             LOG.log(
                 f"Multistage dockerfile, building target {MULTI_STAGE_BUILD_STEP_NAME}..."
             )
-            image = self._client.images.build(
+            image, stream = self._client.images.build(
                 path=self._path,
                 dockerfile=dockerfile,
                 tag="taktile-cli-test",
-                nocache=nocache,
+                nocache=not cache,
                 target=MULTI_STAGE_BUILD_STEP_NAME,
                 buildargs=buildargs,
                 forcerm=True,
@@ -90,22 +96,38 @@ class DockerManager:
             self._patch_docker_file(
                 input_docker_file=dockerfile, output=TESTING_DOCKERFILE
             )
-            image = self._client.images.build(
+            image, stream = self._client.images.build(
                 path=self._path,
                 dockerfile=TESTING_DOCKERFILE,
                 tag="taktile-cli-test",
-                nocache=nocache,
+                nocache=not cache,
                 forcerm=True,
             )
             self._remove_patched_docker_file()
 
-        return image[0].id
+        for chunk in stream:
+            if "stream" in chunk:
+                for line in chunk["stream"].splitlines():
+                    LOG.trace("> " + line)
+
+        return image.id
 
     def test_import(self, image_id: str):
+        client_name = "tktl" if not settings.FUTURE_ENDPOINTS else "client"
+        command = f"python -c 'from src.endpoints import {client_name}'"
         try:
-            container = self._client.containers.run(
-                image_id, "python -c 'from src.endpoints import tktl'", detach=True,
-            )
+            container = self._client.containers.run(image_id, command, detach=True,)
+            self.stream_logs(container)
+
+            status = container.wait()
+            return status, container
+        finally:
+            container.remove()
+
+    def test_endpoint_sample(self, image_id: str):
+        try:
+            command = f"python /app/scripts/endpoint_sample_test{'_future' if settings.FUTURE_ENDPOINTS else ''}.py"
+            container = self._client.containers.run(image_id, command, detach=True)
             self.stream_logs(container)
 
             status = container.wait()
@@ -132,7 +154,11 @@ class DockerManager:
             image_id,
             detach=detach,
             entrypoint="/start-rest.sh",
-            environment={"AUTH_ENABLED": auth_enabled},
+            environment={
+                "AUTH_ENABLED": auth_enabled,
+                "TAKTILE_GIT_SHA": "local-run",
+                "TAKTILE_GIT_REF": "local-run",
+            },
             ports={"80/tcp": 8080},
             remove=True,
             stderr=True,
@@ -146,7 +172,11 @@ class DockerManager:
             image_id,
             detach=detach,
             entrypoint="/start-flight.sh",
-            environment={"AUTH_ENABLED": auth_enabled},
+            environment={
+                "AUTH_ENABLED": auth_enabled,
+                "TAKTILE_GIT_SHA": "local-run",
+                "TAKTILE_GIT_REF": "local-run",
+            },
             ports={"5005/tcp": 5005},
             remove=True,
             stderr=True,
@@ -166,8 +196,10 @@ class DockerManager:
 
     def run_profiling_container(self):
         try:
+            image_name = f"taktile/taktile-profiler:{_get_profiling_version()}"
+            LOG.debug(f"Using Profiling Image {image_name}")
             container = self._client.containers.run(
-                "taktile/taktile-profiler:latest",
+                image_name,
                 entrypoint="profiler profile -l",
                 network_mode="host",
                 detach=True,
@@ -219,3 +251,19 @@ class DockerManager:
             if kill_on_success:
                 arrow_container.kill()
                 rest_container.kill()
+
+
+def _get_profiling_version() -> str:
+    if settings.TAKTILE_PROFILING_VERSION:
+        return settings.TAKTILE_PROFILING_VERSION
+    else:
+        try:
+            res = requests.get(f"{settings.LOCAL_REST_ENDPOINT}/info").json()
+            if isinstance(res, list):  # Not Future
+                profiling_version = "latest"
+            else:  # Future
+                profiling_version = res.get("profiling", "latest")
+        except RequestException as e:
+            LOG.debug(f"Failed to fetch profiling version from Info {e}")
+            profiling_version = "latest"
+        return profiling_version
