@@ -26,7 +26,7 @@ class RequiredUserProjectPathsT(str, ExtendedEnum):
 
     @classmethod
     def strictly_required_dirs(cls):
-        return {cls.SRC.value, cls.ASSETS.value, cls.TESTS.value}
+        return {cls.SRC.value, cls.ASSETS.value}
 
 
 class DeploymentStateFailed(str, ExtendedEnum):
@@ -78,21 +78,6 @@ class ProjectAssetSourceT(str, ExtendedEnum):
     LFS = "lfs"
 
 
-class InstanceTypeT(str, ExtendedEnum):
-    # Also change in taktile-services: services/deployment-api/app/deployment_api/core/t/konduit.py
-    GP_SMALL = "gp.small"
-    GP_MEDIUM = "gp.medium"
-    GP_LARGE = "gp.large"
-    GP_XLARGE = "gp.xlarge"
-    GP_2XLARGE = "gp.xxlarge"
-    GPU_SMALL = "gpu.small"
-    CPU_SMALL = "cpu.small"
-    CPU_MEDIUM = "cpu.medium"
-    CPU_LARGE = "cpu.large"
-    CPU_XLARGE = "cpu.xlarge"
-    CPU_2XLARGE = "cpu.xxlarge"
-
-
 class EndpointKinds(str, ExtendedEnum):
     CUSTOM = "custom"
     TABULAR = "tabular"
