@@ -1,15 +1,16 @@
+import pathlib
 import typing as t
 
 import numpy as np  # type: ignore
 import pandas as pd  # type: ignore
-from pydantic import BaseModel
+from taktile_types.enums.endpoint import EndpointKinds
 
-from tktl.core.future.t import EndpointKinds
 from tktl.future.registration.exceptions import ValidationError
 from tktl.future.registration.serialization import deserialize, serialize, to_example
 from tktl.future.registration.validation import validate
 from tktl.future.utils import JSONStructure
 
+from .abc import XType, YType
 from .typed import TypedEndpoint
 
 
@@ -18,24 +19,35 @@ class ArrowEndpoint(TypedEndpoint):
 
     @staticmethod
     def supported(
-        *,
-        X: t.Union[pd.Series, pd.DataFrame, np.ndarray, t.Any, BaseModel, None] = None,
-        y: t.Union[pd.Series, pd.DataFrame, np.ndarray, t.Any, BaseModel, None] = None,
-        profile: t.Optional[str] = None,
+        *, X: XType = None, y: YType = None, profile: t.Optional[str] = None,
     ) -> bool:
-        return (
-            profile is None
-            and isinstance(X, (np.ndarray, pd.DataFrame, pd.Series))
-            and isinstance(y, (np.ndarray, pd.DataFrame, pd.Series))
+
+        if profile is not None:
+            return False
+
+        strict = isinstance(X, (np.ndarray, pd.DataFrame, pd.Series)) and isinstance(
+            y, (np.ndarray, pd.DataFrame, pd.Series)
         )
 
+        lazy = isinstance(X, pathlib.Path) and isinstance(y, pathlib.Path)
+
+        return strict or lazy
+
     def deserialize_function(
         self,
     ) -> t.Callable[[str], t.Union[pd.Series, pd.DataFrame, np.ndarray]]:
-        def _deserialize(serial_value):
+        def _deserialize(serial_value, explainer: bool = False):
+
+            minimal_subset = None
+
+            if explainer:
+                minimal_subset = (
+                    set(self._profile_columns) if self._profile_columns else None
+                )
+
             try:
                 value = deserialize(self._X, value=serial_value)
-                value = validate(value, sample=self._X)
+                value = validate(value, sample=self._X, minimal_subset=minimal_subset,)
                 return value
             except ValidationError as exc:
                 raise ValidationError(f"Validation error on input: {str(exc)}") from exc
@@ -57,13 +69,11 @@ class ArrowEndpoint(TypedEndpoint):
     def request_type(self) -> object:
         return JSONStructure
 
-    def request_example(self) -> t.Any:
+    def request_example(self) -> str:
         return to_example(self._X)
 
     def response_type(self) -> object:
-        if isinstance(self._y, pd.DataFrame):
-            return str
         return JSONStructure
 
-    def response_example(self) -> t.Any:
+    def response_example(self) -> str:
         return to_example(self._y)
